@@ -9,6 +9,7 @@
  * GNU Library General Public License for more details.
  */                                 
 #include <stdlib.h>
+#include <termios.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/ioctl.h>
@@ -479,10 +480,10 @@ void self_info(void){
 
   fprintf(stderr,
     "personality=0x%08x (from \"%s\")\n"
-    "EUID=%d TTY=%d,%d Hertz=%Ld PAGE_SIZE=%d page_size=%d\n",
+    "EUID=%d TTY=%d,%d Hertz=%Ld page_size=%d\n",
     personality, saved_personality_text,
     cached_euid, (int)major(cached_tty), (int)minor(cached_tty), Hertz,
-    (int)(PAGE_SIZE), (int)(page_size)
+    (int)(page_size)
   );
 
   fprintf(stderr,
