@@ -609,7 +609,7 @@ static int pr_class(char *restrict const outbuf, const proc_t *restrict const pp
   case  0: return snprintf(outbuf, COLWID, "TS");  // SCHED_OTHER
   case  1: return snprintf(outbuf, COLWID, "FF");  // SCHED_FIFO
   case  2: return snprintf(outbuf, COLWID, "RR");  // SCHED_RR
-  case  3: return snprintf(outbuf, COLWID, "#3");  // SCHED_BATCH? (will be "B")
+  case  3: return snprintf(outbuf, COLWID, "B");   // SCHED_BATCH? (will be "B")
   case  4: return snprintf(outbuf, COLWID, "#4");  // SCHED_ISO? (Con Kolivas)
   case  5: return snprintf(outbuf, COLWID, "#5");  //
   case  8: return snprintf(outbuf, COLWID, "#8");  //
@@ -1340,7 +1340,6 @@ static const format_struct format_array[] = {
 {"label",     "LABEL",   pr_context,  sr_nop,    31,  0,     SGI, ET|LEFT},
 {"lastcpu",   "C",       pr_psr,      sr_nop,     3,   0,    BSD, TO|RIGHT}, // DragonFly
 {"lim",       "LIM",     pr_lim,      sr_rss_rlim, 5,  0,    BSD, AN|RIGHT},
-{"lockname",  "LOCK",    pr_nop,      sr_nop,     6, WCH,    BSD, TO|WCHAN}, /* mutex (FreeBSD) */
 {"login",     "LOGNAME", pr_nop,      sr_nop,     8,   0,    BSD, AN|LEFT}, /*logname*/   /* double check */
 {"logname",   "LOGNAME", pr_nop,      sr_nop,     8,   0,    XXX, AN|LEFT}, /*login*/
 {"longtname", "TTY",     pr_tty8,     sr_tty,     8,   0,    DEC, PO|LEFT},
